@@ -49,8 +49,7 @@ class QGridLeaf(abjad.rhythmtrees.RhythmTreeMixin, uqbar.containers.UniqueTreeNo
         """
         pulse_duration = abjad.Duration(pulse_duration)
         total_duration = pulse_duration * self.preprolated_duration
-        maker = abjad.NoteMaker()
-        return maker(0, total_duration)
+        return abjad.makers.make_notes(0, total_duration)
 
     def __graph__(self, **keywords: None) -> uqbar.graphs.Graph:
         """
@@ -193,7 +192,7 @@ class QGrid:
         ...
         QEventProxy(q_event=PitchedQEvent(offset=Offset((750, 1)), pitches=(NamedPitch("cs'"),), index=None, attachments=()), offset=Offset((3, 4)))
 
-    Used internally by the ``Quantizer``.
+    Used internally by the ``quantize`` function.
     """
 
     ### CLASS VARIABLES ###
